@@ -122,8 +122,8 @@ class Joint:
             "namespace": "",
         },
     )
-    pose: "Joint.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Joint.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -772,8 +772,8 @@ class Joint:
             defined inside the parent that this frame is attached to.
         """
 
-        pose: "Joint.Frame.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Joint.Frame.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -798,7 +798,7 @@ class Joint:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -821,7 +821,7 @@ class Joint:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
